/**
 *
 *  Desktop Motion Sensor Driver
 *
 *  1.0.0 - POC 
 *
 */
// import groovy.json.JsonSlurper

def getVersion(){
    def version = "1.0.0"
	return  version
}


metadata {
	definition (
		name: "Cobra Desktop Motion Sensor",
		namespace: "Cobra",
		author: "Andrew Parker",
            
		)
    
	{
        capability "MotionSensor"
        capability "Switch" 
        command "active"
        command "inactive"
	}

	preferences {

    
	input("ip", "string", title:"Computer IP Address", description:"e.g. 192.168.1.100", defaultValue:"" , required: true) 
    input name: "txtEnable", type: "bool", title: "Enable Logging", defaultValue: true

	}
}

def initialize() {
	log.info "initialize"
	if(txtEnable) log.info "initialize"
}

def installed() {
    log.debug "Installed"
 
}

def uninstalled() {
    unschedule()
    log.debug "Uninstalled"
}

def updated() {
    unschedule()
    def iphex = convertIPtoHex(settings.ip)
    log.info "Setting DNI = ${iphex}"
    device.setDeviceNetworkId("${iphex}")
    state.status = "inactive"
    sendEvent(name: "switch", value:"off") 
    sendEvent(name: "motion", value:"inactive")

}

def parse(String message) {
        def msg = stringToMap(message)
        def headers = new String(msg.headers.decodeBase64())
        if(headers.contains("inactive")){ 
        off()}
        else if(headers.contains("active")){ 
        on()} 
}

private String convertIPtoHex(ipAddress) { 
    String hex = ipAddress.tokenize( '.' ).collect {  String.format( '%02x', it.toInteger() ) }.join()
    return hex.toUpperCase()
}

def off() {
    if(state.status == "active"){
    if(txtEnable) log.info "Switching  off.."
    sendEvent(name: "switch", value:"off") 
    sendEvent(name: "motion", value:"inactive")
    state.status = "inactive"    
    }
}
def on() {
    if(state.status == "inactive"){
    if(txtEnable) log.info "Switching  on.."
    sendEvent(name: "switch", value:"on") 
    sendEvent(name: "motion", value:"active")
    state.status = "active"    
    }
}
def active(){
    if(state.status == "inactive"){
    if(txtEnable) log.info "Active.."
    sendEvent(name: "motion", value:"active") 
    sendEvent(name: "switch", value:"on") 
    state.status = "active"
    }
}
def inactive(){
    if(state.status == "active"){
    if(txtEnable) log.info "Inactive.."
    sendEvent(name: "motion", value:"inactive") 
    sendEvent(name: "switch", value:"off") 
    state.status = "inactive"
    }
}


def logsOff(){
	log.warn "debug logging auto disabled..."
	device.updateSetting("debugOutput",[value:"false",type:"bool"])
	device.updateSetting("debugParse",[value:"false",type:"bool"])
}

private logDebug(msg) {
	if (settings?.debugOutput || settings?.debugOutput == null) {
	log.debug "$msg"
	}
}


